library(car)
library(stargazer)
library(modelsummary)
library(RColorBrewer)
library(xtable)

#########summarySE function#########
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- plyr::rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}

#############################################################

GrHs.data<-read.csv(file="/Users/ryokooono/Dropbox/R_codes_datasets/LegumeRhizobiaDataset/LR_Fall_2016_Final.csv")

GrHs.rhizobia <- GrHs.data[-which(GrHs.data$Rhizobia_treatment =="Control"),]
GrHs.rhizobia <- GrHs.rhizobia[-which(GrHs.rhizobia$No_of_nodules<5),]

GrHs.rhizobia <- within(GrHs.rhizobia, N_treatment <- relevel(N_treatment, ref = "none"))
GrHs.rhizobia <- within(GrHs.rhizobia, CO2_treatment <- relevel(CO2_treatment, ref = "ambient"))
GrHs.rhizobia <- within(GrHs.rhizobia, Rhizobia_treatment <- relevel(Rhizobia_treatment, ref = "CE3"))

######Plant shoot biomass######
shapiro.test(GrHs.rhizobia$shoot_wt) #Normal

shoot_model = lm(shoot_wt~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
print.xtable(xtable(shoot_model, digits = 3), type="html", file="Shoot_GH.html")


shoot_wt_aov<-aov(shoot_wt~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
shoot_HSD <- TukeyHSD(x=shoot_wt_aov)

shoot_HSD.levels <- shoot_HSD$`N_treatment:CO2_treatment:Rhizobia_treatment`[,4]
shoot_HSD.labels <- data.frame(multcompLetters(shoot_HSD.levels)['Letters'], reversed = TRUE)
shoot_HSD.labels$treatment=rownames(shoot_HSD.labels)

#correct order for shoot_HSD.labels
shoot_HSD.labels=shoot_HSD.labels[c(8,1,2,3,4,5,6,7) , ]

df_shoot <- summarySE(GrHs.rhizobia, measurevar="shoot_wt", na.rm=TRUE,
                     groupvars=c("CO2_treatment", "N_treatment", "Rhizobia_treatment"))
#correct order for df
df_shoot=df_shoot[c(1,3,5,7,2,4,6,8) , ]

df_shoot$TukeyLetter <-shoot_HSD.labels$Letters

df_shoot$x <- c(0.75,1.25,1.75,2.25,0.75,1.25,1.75,2.25)
df_shoot$y <- c(0.4,0.46,0.45,0.6,0.45,0.44,0.47,0.63)

#Go back to original order
df_shoot <- within(df_shoot, N_treatment <- relevel(N_treatment, ref = "none"))
levels(df_shoot$Rhizobia_treatment)[levels(df_shoot$Rhizobia_treatment)=="CE3"] <- "Wild-type"
levels(df_shoot$Rhizobia_treatment)[levels(df_shoot$Rhizobia_treatment)=="SAM100"] <- "PHB-negative"



ShootWt_GH <-ggplot(df_shoot, aes(x = CO2_treatment, y = shoot_wt, fill = N_treatment)) +   
  geom_bar(position = position_dodge(), stat="identity", colour="black") +
  facet_wrap(~Rhizobia_treatment) +
  geom_errorbar(aes(ymin=shoot_wt-se, ymax=shoot_wt+se), width=.2,
                position=position_dodge(.9)) + theme_bw() +
  scale_fill_manual(values = c("white","grey"), name = "",
                    labels = c("No nitrate","5 mM nitrate")) +
  theme(axis.text.x=element_text(size=10), axis.text.y=element_text(size=14), 
        legend.text=element_text(size=14), axis.title =element_text(size=14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
            panel.border = element_blank(),
        legend.position = "none",
        axis.line = element_line(colour = "black"),
        legend.title=element_text(size=14)) +
  xlab("") + labs(tag = "a") +
  ylab("Shoot dry weight (g)") +
  geom_text(size = 4,mapping = aes(x = x, y = y, label = TukeyLetter, fill = NULL)) 

######Plant root biomass######

root_wt_aov<-aov(root_wt~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
root_HSD <- TukeyHSD(x=root_wt_aov)

root_HSD.levels <- root_HSD$`N_treatment:CO2_treatment:Rhizobia_treatment`[,4]
root_HSD.labels <- data.frame(multcompLetters(root_HSD.levels)['Letters'], reversed = TRUE)
root_HSD.labels$treatment=rownames(root_HSD.labels)

#correct order for root_HSD.labels
root_HSD.labels=root_HSD.labels[c(8,1,2,3,4,5,6,7) , ]

df_root <- summarySE(GrHs.rhizobia, measurevar="root_wt", na.rm=TRUE,
                      groupvars=c("CO2_treatment", "N_treatment", "Rhizobia_treatment"))
#correct order for df
df_root=df_root[c(1,3,5,7,2,4,6,8) , ]

df_root$TukeyLetter <-root_HSD.labels$Letters

df_root$x <- c(0.75,1.25,1.75,2.25,0.75,1.25,1.75,2.25)
df_root$y <- c(0.4,0.46,0.45,0.6,0.45,0.44,0.47,0.63)

#Go back to original order
df_root <- within(df_root, N_treatment <- relevel(N_treatment, ref = "none"))
levels(df_root$Rhizobia_treatment)[levels(df_root$Rhizobia_treatment)=="CE3"] <- "Wild-type"
levels(df_root$Rhizobia_treatment)[levels(df_root$Rhizobia_treatment)=="SAM100"] <- "PHB-negative"

RootWt_GH <-ggplot(df_root_wt, aes(x = CO2_treatment, y = -root_wt, fill = N_treatment)) +   
  geom_bar(position = position_dodge(), stat="identity", colour="black") +
  facet_wrap(~Rhizobia_treatment) +
  geom_errorbar(aes(ymin=-root_wt-se, ymax=-root_wt+se), width=.2,
                position=position_dodge(.9)) + theme_bw() +
  scale_fill_manual(values = c("white","grey"), name = "",
                    labels = c("No nitrate","5 mM nitrate")) +
  theme(axis.text.y=element_text(size=14), 
        legend.text=element_text(size=14), axis.title =element_text(size=14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour = "black"),
        legend.title=element_text(size=14),
        legend.position = "none",
        strip.background = element_blank(),
        strip.text.x = element_blank(),
        axis.text.x = element_blank(),
        plot.margin = margin(-30, 5.5, 5.5, 5.5, "pt")) +
  scale_y_continuous(breaks = c(-0.3,-0.2,-0.1,0), 
                     labels = c("0.3","0.2","0.1","0")) +
  scale_x_discrete(position = "top")+ 
  xlab("") + 
  ylab("Root dry weight (g)") +
  geom_text(size = 4,mapping = aes(x = x, y = y, label = TukeyLetter, fill = NULL)) 

png('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_shoot_root.png', units="in", width=5, height=6, res=300)
grid.arrange(ShootWt_GH, RootWt_GH, ncol = 1,heights =c(1,0.6))
dev.off()


tiff('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_shoot_root.tiff', units="in", width=5, height=6, res=600)
grid.arrange(ShootWt_GH, RootWt_GH, ncol = 1,heights =c(1,0.6))
dev.off()


######Plant root biomass stat######
shapiro.test(GrHs.rhizobia$root_wt) #Normal

root_model = lm(root_wt~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
print.xtable(xtable(root_model, digits = 3), type="html", file="Root_GH.html")

#######Plant N percent#####
GrHs.shoot.N <- GrHs.rhizobia[-which(is.na(GrHs.rhizobia$X..N)),]

shapiro.test(GrHs.shoot.N$X..N) #Not normal
shapiro.test((GrHs.shoot.N$X..N)^(1/2)) #Normal
GrHs.shoot.N$normal_Nper <- GrHs.shoot.N$X..N^(1/2)

N_per_norm_model = lm(normal_Nper~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.shoot.N)
print.xtable(xtable(N_per_norm_model, digits = 3), type="html", file="N_per_norm_GH.html")

N_per_model = lm(X..N~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.shoot.N)
print.xtable(xtable(N_per_model, digits = 3), type="html", file="N_per_raw_GH.html")

Nper_aov<-aov(normal_Nper~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.shoot.N)
Nper_HSD <- TukeyHSD(x=Nper_aov)

Nper_HSD.levels <- Nper_HSD$`N_treatment:CO2_treatment:Rhizobia_treatment`[,4]
Nper_HSD.labels <- data.frame(multcompLetters(Nper_HSD.levels)['Letters'], reversed = TRUE)
Nper_HSD.labels$treatment=rownames(Nper_HSD.labels)

#correct order for Nper_HSD.labels
Nper_HSD.labels=Nper_HSD.labels[c(1,8,3,2,5,4,7,6) , ]

df_Nper <- summarySE(GrHs.shoot.N, measurevar="X..N", na.rm=TRUE,
                     groupvars=c("CO2_treatment", "N_treatment", "Rhizobia_treatment"))
#correct order for df
df_Nper=df_Nper[c(3,1,7,5,4,2,8,6) , ]

df_Nper$TukeyLetter <-Nper_HSD.labels$Letters

df_Nper$x <- c(0.75,1.25,1.75,2.25,0.75,1.25,1.75,2.25)
df_Nper$y <- c(2.3,2.3,1.9,1.8,1.8,2.8,1.4,1.8)

#Go back to original order
df_Nper <- within(df_Nper, N_treatment <- relevel(N_treatment, ref = "none"))
levels(df_Nper$Rhizobia_treatment)[levels(df_Nper$Rhizobia_treatment)=="CE3"] <- "Wild-type"
levels(df_Nper$Rhizobia_treatment)[levels(df_Nper$Rhizobia_treatment)=="SAM100"] <- "PHB-negative"

Nper_GH <- ggplot(df_Nper, aes(x = CO2_treatment, y = X..N, fill = N_treatment)) +   
  geom_bar(position = position_dodge(), stat="identity", colour="black") +
  facet_wrap(~Rhizobia_treatment) +
  geom_errorbar(aes(ymin=X..N-se, ymax=X..N+se), width=.2,
                position=position_dodge(.9)) + theme_bw() +
  scale_fill_manual(values = c("white","grey"), name = "",
                    labels = c("No nitrate","5 mM nitrate")) +
  theme(axis.text.x=element_text(size=10), axis.text.y=element_text(size=14), 
        legend.text=element_text(size=14), axis.title =element_text(size=14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),legend.position = "none",
        axis.line = element_line(colour = "black"),
        legend.title=element_text(size=14)) +
  xlab("") + labs(tag = "b") +
  ylab("Nitrogen %") +
  geom_text(size = 4,mapping = aes(x = x, y = y, label = TukeyLetter, fill = NULL)) 


############Plant N total##########

shapiro.test(GrHs.shoot.N$Total.N.in.shoot) #Normal

Shoot_N_model = lm(Total.N.in.shoot~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.shoot.N)
print.xtable(xtable(Shoot_N_model, digits = 3), type="html", file="Shoot_N_GH.html")


Ntot_aov<-aov(Total.N.in.shoot~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.shoot.N)
Ntot_HSD <- TukeyHSD(x=Ntot_aov)

Ntot_HSD.levels <- Ntot_HSD$`N_treatment:CO2_treatment:Rhizobia_treatment`[,4]
Ntot_HSD.labels <- data.frame(multcompLetters(Ntot_HSD.levels)['Letters'], reversed = TRUE)
Ntot_HSD.labels$treatment=rownames(Ntot_HSD.labels)

#correct order for Ntot_HSD.labels
Ntot_HSD.labels=Ntot_HSD.labels[c(1,8,3,2,5,4,7,6) , ]

df_Ntot <- summarySE(GrHs.shoot.N, measurevar="Total.N.in.shoot", na.rm=TRUE,
                     groupvars=c("CO2_treatment", "N_treatment", "Rhizobia_treatment"))
#correct order for df
df_Ntot=df_Ntot[c(3,1,7,5,4,2,8,6) , ]

df_Ntot$TukeyLetter <-Ntot_HSD.labels$Letters

df_Ntot$x <- c(0.75,1.25,1.75,2.25,0.75,1.25,1.75,2.25)
df_Ntot$y <- c(7.5,9,7.3,9.5,6.7,9.5,6.5,9.2)

#Go back to original order
df_Ntot <- within(df_Ntot, N_treatment <- relevel(N_treatment, ref = "none"))
levels(df_Ntot$Rhizobia_treatment)[levels(df_Ntot$Rhizobia_treatment)=="CE3"] <- "Wild-type"
levels(df_Ntot$Rhizobia_treatment)[levels(df_Ntot$Rhizobia_treatment)=="SAM100"] <- "PHB-negative"


NShoot_GH_v2 <- ggplot(df_Ntot, aes(x = CO2_treatment, y = Total.N.in.shoot, fill = N_treatment)) +   
  geom_bar(position = position_dodge(), stat="identity", colour="black") +
  facet_wrap(~Rhizobia_treatment) +
  geom_errorbar(aes(ymin=Total.N.in.shoot-se, ymax=Total.N.in.shoot+se), width=.2,
                position=position_dodge(.9)) + theme_bw() +
  scale_fill_manual(values = c("white","grey"), name = "",
                    labels = c("No nitrate","5 mM nitrate")) +
  theme(axis.text.x=element_text(size=10), axis.text.y=element_text(size=14), 
        legend.text=element_text(size=14), axis.title =element_text(size=14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        legend.position = "right",
        panel.border = element_blank(),
        axis.line = element_line(colour = "black"),
        legend.title=element_text(size=14)) +
   xlab("") +
 # xlab(bquote(~CO[2]~  "treatment")) +
  geom_text(size = 4,mapping = aes(x = x, y = y, label = TukeyLetter, fill = NULL))  +
  ylab("Nitrogen in shoot (mg)") + labs(tag = "c") 

legend<-get_legend(NShoot_GH_v2)
library(gtable)
library(grid)
g1 <- ggplotGrob(ShootWt_GH)
g2 <- ggplotGrob(Nper_GH)
g3 <- ggplotGrob(NShoot_GH_v2)
g4 <- ggplotGrob(RootWt_GH)

png('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_Fig1_v2.png', units="in", width=10, height=5, res=300)
ggarrange(g1, g2, g3,g4,nrow = 2, ncol = 3, align = "v", heights = c(1,0.6))
dev.off()

png('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_Fig1_legend.png', units="in", width=5, height=6, res=300)
grid.arrange(legend)
dev.off()


tiff('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_shoot_root.tiff', units="in", width=5, height=6, res=600)
grid.arrange(ShootWt_GH, RootWt_GH, ncol = 1,heights =c(1,0.6))
dev.off()


############Plant delta15N##########

shapiro.test(GrHs.shoot.N$d15N) #Normal

Shoot_15N_model = lm(d15N~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.shoot.N)
print.xtable(xtable(Shoot_15N_model, digits = 3), type="html", file="Shoot_15N_GH.html")

##TukeyHSD for delta15N
GrHs.shoot.N <- within(GrHs.shoot.N, N_treatment <- relevel(N_treatment, ref = "5mM"))
Shoot_15N_model_HSD <- TukeyHSD(aov(d15N~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.shoot.N))

d15N.levels <- Shoot_15N_model_HSD$`N_treatment:CO2_treatment:Rhizobia_treatment`[,4]
d15N.labels <- data.frame(multcompLetters(d15N.levels)['Letters'], reversed = TRUE)
d15N.labels$treatment=rownames(d15N.labels)

#correct order for d15N.labels
d15N.labels=d15N.labels[c(1,8,3,2,5,4,7,6) , ]



df_d15N <- summarySE(GrHs.shoot.N, measurevar="d15N", 
                     groupvars=c("CO2_treatment", "N_treatment", "Rhizobia_treatment"))
#correct order for df
df_d15N=df_d15N[c(3,1,7,5,4,2,8,6) , ]

df_d15N$TukeyLetter <-d15N.labels$Letters

df_d15N$x <- c(0.75,1.25,1.75,2.25,0.75,1.25,1.75,2.25)
df_d15N$y <- c(0.25,1.1,0.25,1,0.25,1.3,0.5,1.3)

#Go back to original order
df_d15N <- within(df_d15N, N_treatment <- relevel(N_treatment, ref = "none"))
levels(df_d15N$Rhizobia_treatment)[levels(df_d15N$Rhizobia_treatment)=="CE3"] <- "Wild-type"
levels(df_d15N$Rhizobia_treatment)[levels(df_d15N$Rhizobia_treatment)=="SAM100"] <- "PHB-negative"


N15_GH <- ggplot(df_d15N, aes(x = CO2_treatment, y = d15N, fill = N_treatment)) +   
  geom_bar(position = position_dodge(), stat="identity", colour="black") +
  facet_wrap(~Rhizobia_treatment) +
  geom_errorbar(aes(ymin=d15N-se, ymax=d15N+se), width=.2,
                position=position_dodge(.9)) + theme_bw() +
  scale_fill_manual(values = c("white","grey"), name = "",
                    labels = c("No nitrate","5 mM nitrate")) +
  theme(axis.text.x=element_text(size=10), axis.text.y=element_text(size=14), 
        axis.title =element_text(size=14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(), 
        axis.line = element_line(colour = "black"),
        legend.position = "bottom",
        legend.title=element_text(size=14)) +
  xlab("") +
  ylab(expression(delta ^15 ~N)) +
  geom_text(size = 4,mapping = aes(x = x, y = y, label = TukeyLetter, fill = NULL)) 


png('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_N15_supp.png', units="in", width=4, height=4, res=300)
grid.arrange(N15_GH, ncol = 1)
dev.off()

tiff('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_N15_supp.tiff', units="in", width=4, height=4, res=600)
grid.arrange(N15_GH, ncol = 1)
dev.off()


############Nodule numbers##########

shapiro.test(GrHs.rhizobia$No_of_nodules) #Not normal
shapiro.test((GrHs.rhizobia$No_of_nodules)^(1/2)) #Closer to normal
GrHs.rhizobia$normal_nod <- GrHs.rhizobia$No_of_nodules^(1/2)


normal_nod_model = lm(normal_nod~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
print.xtable(xtable(normal_nod_model, digits = 2), type="html", file="Nod_no_norm_GH.html")

nod_model = lm(No_of_nodules~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
print.xtable(xtable(nod_model, digits = 2), type="html", file="Nod_no_GH.html")

#This makes ambient CE3 no nitrate have letter "a" in Tukey's HSD
GrHs.rhizobia <- within(GrHs.rhizobia, N_treatment <- relevel(N_treatment, ref = "5mM"))

NodNo_aov<-aov(normal_nod~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
NodNo_HSD <- TukeyHSD(x=NodNo_aov)

NodNo_HSD.levels <- NodNo_HSD$`N_treatment:CO2_treatment:Rhizobia_treatment`[,4]
NodNo_HSD.labels <- data.frame(multcompLetters(NodNo_HSD.levels, reversed = FALSE)['Letters'])
NodNo_HSD.labels$treatment=rownames(NodNo_HSD.labels)

#correct order for NodNo_HSD.labels
NodNo_HSD.labels=NodNo_HSD.labels[c(1,8,3,2,5,4,7,6) , ]

df_NodNo <- summarySE(GrHs.rhizobia, measurevar="No_of_nodules", na.rm=TRUE,
                     groupvars=c("CO2_treatment", "N_treatment", "Rhizobia_treatment"))
#correct order for df
df_NodNo=df_NodNo[c(3,1,7,5,4,2,8,6) , ]

df_NodNo$TukeyLetter <-NodNo_HSD.labels$Letters
df_NodNo$TukeyLetter<-chartr("d","e",df_NodNo$TukeyLetter)
df_NodNo$TukeyLetter<-chartr("b","d",df_NodNo$TukeyLetter)
df_NodNo$TukeyLetter<-chartr("e","b",df_NodNo$TukeyLetter)

df_NodNo$x <- c(0.75,1.25,1.75,2.25,0.75,1.25,1.75,2.25)
df_NodNo$y <- c(130,80,119,115,55,25,50,45)

#Go back to original order
levels(df_NodNo$Rhizobia_treatment)[levels(df_NodNo$Rhizobia_treatment)=="CE3"] <- "Wild-type"
levels(df_NodNo$Rhizobia_treatment)[levels(df_NodNo$Rhizobia_treatment)=="SAM100"] <- "PHB-negative"

df_NodNo <- within(df_NodNo, N_treatment <- relevel(N_treatment, ref = "none"))


NodNo_GH <- ggplot(df_NodNo, aes(x = CO2_treatment, y = No_of_nodules, fill = N_treatment)) + 
  geom_bar(position = position_dodge(), stat="identity", colour="black") +
  facet_wrap(~Rhizobia_treatment) +
  geom_errorbar(aes(ymin=No_of_nodules-se, ymax=No_of_nodules+se), width=.2,
                position=position_dodge(.9)) + theme_bw() +
  ylab("Number of nodules") +
  scale_fill_manual(values = c("white","grey"), name = "",
                    labels = c("No nitrate","5 mM nitrate")) +
  xlab("") +theme(legend.position="none") +
  theme(axis.text.x=element_text(size=10), axis.text.y=element_text(size=14), 
        axis.title =element_text(size=14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour = "black")) +labs(tag = "a") +
  geom_text(size = 4,mapping = aes(x = x, y = y, label = TukeyLetter, fill = NULL)) 




############Average_wt_nodule##########
shapiro.test(GrHs.rhizobia$Avg_wt_per_nodule) #Not normal
shapiro.test((GrHs.rhizobia$Avg_wt_per_nodule)^(1/2)) #Closer to normal
GrHs.rhizobia$normal_avgwt <- GrHs.rhizobia$Avg_wt_per_nodule^(1/2)

avg_wt_model = lm(Avg_wt_per_nodule*1000~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)

normal_avg_wt_model = lm(normal_avgwt~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
print.xtable(xtable(normal_avg_wt_model, digits = 3), type="html", file="Avg_wt_norm_GH.html")

AvgNodWt_aov<-aov(normal_avgwt~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
AvgNodWt_HSD <- TukeyHSD(x=AvgNodWt_aov)

AvgNodWt_HSD.levels <- AvgNodWt_HSD$`N_treatment:CO2_treatment:Rhizobia_treatment`[,4]
AvgNodWt_HSD.labels <- data.frame(multcompLetters(AvgNodWt_HSD.levels, reversed = FALSE)['Letters'])
AvgNodWt_HSD.labels$treatment=rownames(AvgNodWt_HSD.labels)

#correct order for NodNo_HSD.labels
AvgNodWt_HSD.labels=AvgNodWt_HSD.labels[c(1,8,3,2,5,4,7,6) , ]

df_AvgWt <- summarySE(GrHs.rhizobia, measurevar="Avg_wt_per_nodule", na.rm=TRUE,
                      groupvars=c("CO2_treatment", "N_treatment", "Rhizobia_treatment"))
#correct order for df
df_AvgWt=df_AvgWt[c(3,1,7,5,4,2,8,6) , ]
df_AvgWt$TukeyLetter <-AvgNodWt_HSD.labels$Letters
df_AvgWt$TukeyLetter<-chartr("d","e",df_AvgWt$TukeyLetter)
df_AvgWt$TukeyLetter<-chartr("b","d",df_AvgWt$TukeyLetter)
df_AvgWt$TukeyLetter<-chartr("e","b",df_AvgWt$TukeyLetter)


df_AvgWt$y <- c(2.2,1.6,3.4,3.5,3.8,1.3,4.2,2.1)
df_AvgWt$x <- c(0.75,1.25,1.75,2.25,0.75,1.25,1.75,2.25)

levels(df_AvgWt$Rhizobia_treatment)[levels(df_AvgWt$Rhizobia_treatment)=="CE3"] <- "Wild-type"
levels(df_AvgWt$Rhizobia_treatment)[levels(df_AvgWt$Rhizobia_treatment)=="SAM100"] <- "PHB-negative"

df_AvgWt <- within(df_AvgWt, N_treatment <- relevel(N_treatment, ref = "none"))

AvgNodWt_GH <- ggplot(df_AvgWt, aes(x = CO2_treatment, y = Avg_wt_per_nodule*1000, fill = N_treatment)) + 
  geom_bar(position = position_dodge(), stat="identity", colour="black") +
  facet_wrap(~Rhizobia_treatment) +
  geom_errorbar(aes(ymin=Avg_wt_per_nodule*1000-se*1000, ymax=Avg_wt_per_nodule*1000+se*1000), width=.2,
                position=position_dodge(.9)) + theme_bw() +
  ylab("Average nodule weight (mg)") +
  scale_fill_manual(values = c("white","grey"), name = "",
                    labels = c("No nitrate","5 mM nitrate")) +
  xlab("") +
  theme(legend.position="none") +
  theme(axis.text.x=element_text(size=10), axis.text.y=element_text(size=14), 
        axis.title =element_text(size=14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour = "black")) +labs(tag = "b") +
  geom_text(size = 4,mapping = aes(x = x, y = y, label = TukeyLetter, fill = NULL)) 


############Tot_wt_nodule##########

shapiro.test(GrHs.rhizobia$Total_nodule_wtt) #Not normal
shapiro.test((GrHs.rhizobia$Total_nodule_wtt)^(1/2)) #Closer to normal
GrHs.rhizobia$normal_totwt <- GrHs.rhizobia$Total_nodule_wtt^(1/2)

tot_wt_model = lm(normal_totwt~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
print.xtable(xtable(tot_wt_model, digits = 3), type="html", file="Tot_wt_norm_GH.html")

tot_wt_norm_model = lm(Total_nodule_wtt~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.rhizobia)
print.xtable(xtable(tot_wt_norm_model, digits = 3), type="html", file="Tot_wt_GH.html")

############Shoot N per Tot_wt_nodule##########
GrHs.shoot.N_noN <- GrHs.shoot.N[-which(GrHs.shoot.N$N_treatment =="5mM"),]

GrHs.shoot.N_noN$ShootNperTotNod <- GrHs.shoot.N_noN$Total.N.in.shoot/GrHs.shoot.N_noN$Total_nodule_wtt

shapiro.test(GrHs.shoot.N_noN$ShootNperTotNod) #Very NOT Normal
shapiro.test((GrHs.shoot.N_noN$ShootNperTotNod)^(1/2)) #Very NOT Normal


Shoot_N_model = lm(Total.N.in.shoot~N_treatment*CO2_treatment*Rhizobia_treatment, data = GrHs.shoot.N)
print.xtable(xtable(Shoot_N_model, digits = 3), type="html", file="Shoot_N_GH.html")
